"""Top-level package for r_freeze."""

__author__ = """Chinmay Shah"""
__email__ = "chinmayshah3899@gmail.com"
__version__ = "0.1.1"
